/**
 * Compiles C/C++ source.
 * @category Compilation
 * @param {string} compilerName Compiler to use.
 * @param {string} inputFile Source file to compile.
 * @param {string} outputFile Output file name.
 * @param {boolean} link Should result be linked.
 * @returns {Promise<{ inputFile: string }>}
 * @throws {@link CompilationFailedError} if compilation fails.
 */
export declare function compileWith(compilerName: string, inputFile: string, outputFile: string, link: boolean): Promise<{
    inputFile: string;
}>;
/**
 * Compiles C/C++ source using gcc.
 * @category Compilation
 * @param {string} inputFile Source file to compile.
 * @param {string} outputFile Output file name.
 * @param {boolean} link Should result be linked.
 * @returns {Promise<{ inputFile: string }>}
 * @throws {@link CompilationFailedError} if compilation fails.
 */
export declare function compileWithGcc(inputFile: string, outputFile: string, link?: boolean): Promise<{
    inputFile: string;
}>;
/**
 * Compiles C/C++ source using g++.
 * @category Compilation
 * @param {string} inputFile Source file to compile.
 * @param {string} outputFile Output file name.
 * @param {boolean} link Should result be linked.
 * @returns {Promise<{ inputFile: string }>}
 * @throws {@link CompilationFailedError} if compilation fails.
 */
export declare function compileWithGPlus(inputFile: string, outputFile: string, link?: boolean): Promise<{
    inputFile: string;
}>;
/**
 * Compiles C/C++ source using clang.
 * @category Compilation
 * @param {string} inputFile Source file to compile.
 * @param {string} outputFile Output file name.
 * @param {boolean} link Should result be linked.
 * @returns {Promise<{ inputFile: string }>}
 * @throws {@link CompilationFailedError} if compilation fails.
 */
export declare function compileWithClang(inputFile: string, outputFile: string, link?: boolean): Promise<{
    inputFile: string;
}>;
/**
 * Compiles C/C++ source using clang++.
 * @category Compilation
 * @param {string} inputFile Source file to compile.
 * @param {string} outputFile Output file name.
 * @param {boolean} link Should result be linked.
 * @returns {Promise<{ inputFile: string }>}
 * @throws {@link CompilationFailedError} if compilation fails.
 */
export declare function compileWithClangPlus(inputFile: string, outputFile: string, link?: boolean): Promise<{
    inputFile: string;
}>;
//# sourceMappingURL=compilation.d.ts.map