/**
 * Checks whether a compiler is in the system path (i.e. PATH).
 * @category Compiler Detection
 * @param {string} compilerName The compiler to look for.
 * @returns {Promise<{compiler: string, version: string}>}
 * @throws {@link CompilerNotFoundError} if specified compiler can't be found.
 */
export declare function checkForCompiler(compilerName: string): Promise<{
    compiler: string;
    version: string;
}>;
/**
 * Checks whether gcc is in the system path (i.e. PATH).
 * @category Compiler Detection
 * @returns {Promise<{compiler: string, version: string}>}
 * @throws {@link CompilerNotFoundError} if gcc can't be found in the system path.
 */
export declare function checkForGcc(): Promise<{
    compiler: string;
    version: string;
}>;
/**
 * Checks whether g++ is in the system path (i.e. PATH).
 * @category Compiler Detection
 * @returns {Promise<{compiler: string, version: string}>}
 * @throws {@link CompilerNotFoundError} if g++ can't be found in the system path.
 */
export declare function checkForGPlus(): Promise<{
    compiler: string;
    version: string;
}>;
/**
 * Checks whether clang is in the system path (i.e. PATH).
 * @category Compiler Detection
 * @returns {Promise<{compiler: string, version: string}>}
 * @throws {@link CompilerNotFoundError} if clang can't be found in the system path.
 */
export declare function checkForClang(): Promise<{
    compiler: string;
    version: string;
}>;
/**
 * Checks whether clang++ is in the system path (i.e. PATH).
 * @category Compiler Detection
 * @returns {Promise<{compiler: string, version: string}>}
 * @throws {@link CompilerNotFoundError} if clang++ can't be found in the system path.
 */
export declare function checkForClangPlus(): Promise<{
    compiler: string;
    version: string;
}>;
//# sourceMappingURL=compilerDetection.d.ts.map